wellformednesstools.Check
=========================

.. inheritance-diagram:: abjad.tools.wellformednesstools.Check.Check.Check
   :private-bases:

.. autoclass:: abjad.tools.wellformednesstools.Check.Check.Check

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.wellformednesstools.Check.Check.Check.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.check

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.report

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.violators

Special Methods
---------------

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.wellformednesstools.Check.Check.Check.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
